@@ -111,13 +111,13 @@ public:
      * @param parent parent object
      * @return created KTextEditor::Document
      */
-    KTextEditor::Document *createDocument(QObject *parent) Q_DECL_OVERRIDE;
+    KTextEditor::Document *createDocument(QObject *parent) override;
 
     /**
      * Returns a list of all documents of this editor.
      * @return list of all existing documents
      */
-    QList<KTextEditor::Document *> documents() Q_DECL_OVERRIDE
+    QList<KTextEditor::Document *> documents() override
     {
         return m_documents.keys();
     }
@@ -128,7 +128,7 @@ public:
      * the hosting application.
      * @param application application object
      */
-    void setApplication(KTextEditor::Application *application) Q_DECL_OVERRIDE
+    void setApplication(KTextEditor::Application *application) override
     {
         // switch back to dummy application?
         m_application = application ? application : &m_dummyApplication;
@@ -138,7 +138,7 @@ public:
      * Current hosting application, if any set.
      * @return current application object or nullptr
      */
-    KTextEditor::Application *application() const Q_DECL_OVERRIDE
+    KTextEditor::Application *application() const override
     {
         return m_application;
     }
@@ -151,7 +151,7 @@ public:
      * return the about data
      * @return about data of this editor part
      */
-    const KAboutData &aboutData() const Q_DECL_OVERRIDE
+    const KAboutData &aboutData() const override
     {
         return m_aboutData;
     }
@@ -165,7 +165,7 @@ public:
      * to the editor, but not saved anywhere automagically, call
      * writeConfig to save them
     */
-    void configDialog(QWidget *parent) Q_DECL_OVERRIDE;
+    void configDialog(QWidget *parent) override;
 
     /**
      * Number of available config pages
@@ -173,14 +173,14 @@ public:
      * and the embedding app should use the configDialog () instead
      * @return number of config pages
      */
-    int configPages() const Q_DECL_OVERRIDE;
+    int configPages() const override;
 
     /**
      * returns config page with the given number,
      * config pages from 0 to configPages()-1 are available
      * if configPages() > 0
      */
-    KTextEditor::ConfigPage *configPage(int number, QWidget *parent) Q_DECL_OVERRIDE;
+    KTextEditor::ConfigPage *configPage(int number, QWidget *parent) override;
 
     /**
      * Kate Part Internal stuff ;)
@@ -351,19 +351,19 @@ public:
      * @param cmd name of command to query for
      * @return found command or 0
      */
-    KTextEditor::Command *queryCommand(const QString &cmd) const Q_DECL_OVERRIDE;
+    KTextEditor::Command *queryCommand(const QString &cmd) const override;
 
     /**
      * Get a list of all registered commands.
      * \return list of all commands
      */
-    QList<KTextEditor::Command *> commands() const Q_DECL_OVERRIDE;
+    QList<KTextEditor::Command *> commands() const override;
 
     /**
      * Get a list of available commandline strings.
      * \return commandline strings
      */
-    QStringList commandList() const Q_DECL_OVERRIDE;
+    QStringList commandList() const override;
 
     /**
      * Copy text to clipboard an remember it in the history
@@ -434,7 +434,7 @@ Q_SIGNALS:
     void clipboardHistoryChanged();
 
 protected:
-    bool eventFilter(QObject *, QEvent *) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *, QEvent *) override;
 
 private Q_SLOTS:
     void updateColorPalette();
